==> kvpnc_0.8.orig.tar.gz: kvpnc-0.8/src/profilemanager.cpp <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include "profilemanager.h"
#include <qwidget.h>
#include <klocale.h>

ProfileManager::ProfileManager( QWidget *parent, const QString& caption, KVpncConfig *GlobalConfig) : KDialogBase( parent, i18n("Profile manager"), true, caption,
		KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
{
	MyprofileWidget = new ProfileWidget( GlobalConfig, this );
	setMainWidget(MyprofileWidget);
	resize(minimumSize());
}

ProfileManager::~ProfileManager() {}

==> kvpnc_0.8.5.1.orig.tar.gz: kvpnc-0.8.5.1/src/profilemanager.cpp <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include "profilemanager.h"
#include <qwidget.h>
#include <klocale.h>

ProfileManager::ProfileManager( QWidget *parent, const QString& caption, KVpncConfig *GlobalConfig) : KDialogBase( parent, "Profile_manager", true, caption,
		KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
{
	MyprofileWidget = new ProfileWidget( GlobalConfig, this );
	setMainWidget(MyprofileWidget);
	resize(minimumSize());
}

ProfileManager::~ProfileManager() {}
